# pitchtrack
collection of pitch (f0, fundamental frequency) tracking algorithms with unified interface

warning: currently this repo is only contains mock API. Actual implementation is here https://github.com/tandav/pitch-detectors (to be merged)

# Installation

```shell
pip install pitchtrack
```

# Usage

```python
import pitchtrack
pitchtrack.test()
```
